==> xdvik-22.76.1.tar.gz: xdvik-22.76.1/texk/xdvik/message-window.h <==
/*
 * Copyright (c) 2002 xdvik development team
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
 * PAUL VOJTA OR ANY OTHER AUTHOR OF THIS SOFTWARE BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 */

#ifndef MESSAGE_WINDOW_H
#define MESSAGE_WINDOW_H

typedef enum popup_message_t_ { MSG_QUESTION, MSG_HELP, MSG_INFO, MSG_WARN, MSG_ERR } popup_message_t;
extern void do_popup_message(popup_message_t type, const char *helptext, const char *format, ...);
extern void do_popup_ok_or_cancel_dialog(const char *helptext,
					 const char *ok_label,
					 void (*ok_callback)(), const XtPointer ok_args,
					 void (*cancel_callback)(), const XtPointer cancel_args,
					 const char *format, ...);
extern void warn_overstrike(void);
extern void raise_message_windows(void);

/* #define MSG_HELP 0 */
/* #define MSG_INFO 1 */
/* #define MSG_WARN 2 */
/* #define MSG_ERR  3 */



/* XawtextScrollWhenNeeded has been ditched in Xaw7
   (e.g. Xfree >= 4.x); from the man page:
   
   The value XawtextScrollWhenNeeded (and whenNeeded, recognized by
   the converter), is accepted for backwards compatibilty with
   resource specifications written for the Xaw6 Text widget, but
   ignored (effectively treated as XawtextScrollNever).

   So we're forced to use `scrollAlways' here.
*/
#define XAW_SCROLL_ALWAYS XawtextScrollAlways

/* the reconfig stuff has been fixed
   in XFree 4.1.0, vendor release 6510 (Slackware 8.0) */
#define BROKEN_RECONFIG ((				\
	(strstr(ServerVendor(DISP), "XFree") != NULL)	\
	&& VendorRelease(DISP) >= 4000			\
	&& VendorRelease(DISP) < 4002			\
	))

#endif /* MESSAGE_WINDOW_H */

==> xdvik-22.77.1.tar.gz: xdvik-22.77.1/texk/xdvik/message-window.h <==
/*
 * Copyright (c) 2002 xdvik development team
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
 * PAUL VOJTA OR ANY OTHER AUTHOR OF THIS SOFTWARE BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 */

#ifndef MESSAGE_WINDOW_H
#define MESSAGE_WINDOW_H

typedef enum popup_message_t_ { MSG_QUESTION, MSG_HELP, MSG_INFO, MSG_WARN, MSG_ERR } popup_message_t;
extern void popup_message(popup_message_t type, const char *helptext, const char *format, ...);
extern void positioned_popup_message(popup_message_t type,
				     int x, int y,
				     const char *helptext, const char *format, ...);
extern void choice_dialog(const char *helptext,
			  const char *ok_label,
			  void (*ok_callback)(XtPointer arg), const XtPointer ok_args,
			  const char *cancel_label,
			  void (*cancel_callback)(XtPointer arg), const XtPointer cancel_args,
			  const char *format, ...);
extern void positioned_choice_dialog(const char *helptext,
				     int x_pos, int y_pos,
				     const char *ok_label,
				     void (*ok_callback)(XtPointer arg), const XtPointer ok_args,
				     const char *cancel_label,
				     void (*cancel_callback)(XtPointer arg), const XtPointer cancel_args,
				     const char *format, ...);
extern void warn_overstrike(void);
extern Boolean raise_message_windows(void);

/* XawtextScrollWhenNeeded has been ditched in Xaw7
   (e.g. Xfree >= 4.x); from the man page:
   
   The value XawtextScrollWhenNeeded (and whenNeeded, recognized by
   the converter), is accepted for backwards compatibilty with
   resource specifications written for the Xaw6 Text widget, but
   ignored (effectively treated as XawtextScrollNever).

   So we're forced to use `scrollAlways' here.
*/
#define XAW_SCROLL_ALWAYS XawtextScrollAlways

/* the reconfig stuff has been fixed
   in XFree 4.1.0, vendor release 6510 (Slackware 8.0) */
#define BROKEN_RECONFIG ((				\
	(strstr(ServerVendor(DISP), "XFree") != NULL)	\
	&& VendorRelease(DISP) >= 4000			\
	&& VendorRelease(DISP) < 4002			\
	))

#endif /* MESSAGE_WINDOW_H */
